import setuptools

setuptools.setup(
    name="warp",
    version="0.0.1",
    author="Willem Pienaar",
    author_email="pypi@willem.co",
    url="https://github.com/woop/warp",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
